@@ -1,4 +1,3 @@
-from typing import AnyStr
 import os
 import tarfile
 import re
@@ -13,13 +12,13 @@ def _safeopen(path):
     return path
 
 
-def compress(src, target_root, ignore: AnyStr, tar_name=None):
+def compress(src, save_root, tar_name=None, ignore=None):
     """ Generating a compressed package using tar.bz2 (for md5 timestep issue).
         If src is a directory, the entire source inside the root would be compressed.
         The tar.bz2 file is named with md5 hash by default.
         param ignore: a regex pattern to ignore some files. (works only in directory mode)
     """
-    tmp_path = _safeopen(target_root) + '/_tmp_compress.tar.bz2'
+    tmp_path = _safeopen(save_root) + '/_tmp_compress.tar.bz2'
     with tarfile.open(tmp_path, 'w:bz2') as tar:
         if os.path.isdir(src):
             for dir_path, _, names in os.walk(src):
